@@ -50,11 +50,13 @@ example document:
 """
 
 import json
+# import sys
 
 from collections import OrderedDict
 
 from scs_core.data.datetime import LocalizedDatetime
-from scs_core.data.json import JSONable
+from scs_core.data.json import JSONify, JSONable
+from scs_core.data.path_dict import PathDict
 from scs_core.data.str import Str
 
 from scs_core.estate.configuration import Configuration
@@ -71,17 +73,29 @@ class ConfigurationSample(Sample):
 
     VERSION = 1.0
 
+    __HIDDEN_VALUES = [
+        'val.aws-api-auth.api-key',
+        'val.shared-secret.key'
+    ]
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
     def construct_from_jdict(cls, jdict, skeleton=False):
+        # print("ConfigurationSample - jdict: %s" % jdict, file=sys.stderr)
+
         if not jdict:
             return None
 
         # Sample...
         tag = jdict.get('tag')
         rec = LocalizedDatetime.construct_from_jdict(jdict.get('rec'))
-        version = jdict.get('ver', cls.DEFAULT_VERSION)
+
+        try:
+            version = float(jdict.get('ver'))
+        except (TypeError, ValueError):
+            version = cls.DEFAULT_VERSION
 
         try:
             val_jdict = json.loads(jdict.get('val'))
@@ -128,10 +142,28 @@ class ConfigurationSample(Sample):
         return False
 
 
+    # ----------------------------------------------------------------------------------------------------------------
+
     def diff(self, other):
         return ConfigurationSample(self.tag, self.rec, self.configuration.diff(other.configuration))
 
 
+    def as_table(self):
+        path_dict = PathDict.construct_from_jstr(JSONify.dumps(self))
+        rows = []
+
+        for path in path_dict.paths():
+            node = path_dict.node(path)
+            value = '' if node is None else node
+
+            key = path[4:] if path.startswith('val.') else path
+            setting = '######' if path in self.__HIDDEN_VALUES else value
+
+            rows.append(','.join((key, str(setting))))
+
+        return rows
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     @property
